@@ -1,15 +1,18 @@
 cqr.mm = function(X, y, tau, beta, maxit, toler)
 {
 
-if(nargs()<5){
-	toler = 1e-3
+if(missing(maxit)){
 	maxit = 200
 }
 
+if(missing(toler)){
+	toler = 1e-3
+	
+}
 n=dim(X)[1]
 k=length(tau)
 
-if(nargs()<4){
+if(missing(beta)){
 	beta=solve(t(X)%*%X,t(X)%*%y)
 }
 
