@@ -12,7 +12,7 @@ arma:: vec betaold,beta=(betar),quantile,u,yh;
 arma::uvec order, index;
 
 
-int place,n=x.n_rows,k=tau.n_elem;
+int n=x.n_rows,k=tau.n_elem;
 int p=x.n_cols;
 double error=10000,epsilon=0.9999;
 //toler=1e-3;
